You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by er...@apache.org on 2006/12/23 19:59:17 UTC

svn commit: r489921 - /directory/trunks/ldapstudio/ldapstudio-dsml-parser/src/main/java/org/apache/directory/ldapstudio/dsmlv2/engine/Dsmlv2Engine.java

Author: ersiner
Date: Sat Dec 23 10:59:17 2006
New Revision: 489921

URL: http://svn.apache.org/viewvc?view=rev&rev=489921
Log:
Renamed a method parameter. Tiny fix while reading the code.

Modified:
    directory/trunks/ldapstudio/ldapstudio-dsml-parser/src/main/java/org/apache/directory/ldapstudio/dsmlv2/engine/Dsmlv2Engine.java

Modified: directory/trunks/ldapstudio/ldapstudio-dsml-parser/src/main/java/org/apache/directory/ldapstudio/dsmlv2/engine/Dsmlv2Engine.java
URL: http://svn.apache.org/viewvc/directory/trunks/ldapstudio/ldapstudio-dsml-parser/src/main/java/org/apache/directory/ldapstudio/dsmlv2/engine/Dsmlv2Engine.java?view=diff&rev=489921&r1=489920&r2=489921
==============================================================================
--- directory/trunks/ldapstudio/ldapstudio-dsml-parser/src/main/java/org/apache/directory/ldapstudio/dsmlv2/engine/Dsmlv2Engine.java (original)
+++ directory/trunks/ldapstudio/ldapstudio-dsml-parser/src/main/java/org/apache/directory/ldapstudio/dsmlv2/engine/Dsmlv2Engine.java Sat Dec 23 10:59:17 2006
@@ -131,16 +131,16 @@
 
     /**
      * Processes the file given and return the result of the operations
      * @param fileName The path to the file
      * @return The XML reponse in DSMLv2 Format
      * @throws XmlPullParserException
      * @throws FileNotFoundException
      */
-    public String processDSML( String fileName ) throws XmlPullParserException, FileNotFoundException
+    public String processDSML( String dsmlInput ) throws XmlPullParserException, FileNotFoundException
     {
         parser = new Dsmlv2Parser();
 
-        parser.setInput( fileName );
+        parser.setInput( dsmlInput );
 
         return processDSML();
     }
@@ -131,16 +131,16 @@
     /**
      * Processes the file given and return the result of the operations
-     * @param fileName The path to the file
+     * @param dsmlInput The path to the file
      * @return The XML reponse in DSMLv2 Format
      * @throws XmlPullParserException